VA.temp <- as.data.frame(cancer.vet)
dimnames(VA.temp)[[2]] <- c("treat", "cell", "stime",
    "status", "Karn", "diag.time","age","therapy")
attach(VA.temp)
VA <- data.frame(stime, status, treat=factor(treat), age,
    Karn, diag.time, cell=factor(cell), prior=factor(therapy))
detach()
VA$Karnc <- VA$Karn - 50
options(contrasts=c("contr.treatment", "contr.poly"))
VA.cox <- coxph(Surv(stime, status) ~ treat + age  + Karn +
                diag.time + cell + prior, VA)
VA.cox3 <- update(VA.cox, ~ treat/Karnc + prior*Karnc
                  + treat:prior + cell/diag.time)

menuVA <- function(treat, age, Karn, diag.time, cell, prior)
{
  treat <- factor(match(treat, c("standard","test")),
                  levels=1:2, labels=levels(VA$treat))
  cell <-
    factor(match(cell, c("squamous","small","adeno","large")),
           levels=1:4, labels=levels(VA$cell))
  prior <- factor(match(prior, c("no", "yes")), levels=1:2,
                  labels=levels(VA$prior))
  nd <- data.frame(treat, age, Karnc=Karn-50, diag.time,
                   cell, prior)
  plot(survfit(VA.cox3, nd, conf.type="log-log"))
  invisible()
}

guiCreate("FunctionInfo", Name = "menuVA",
    Function = "menuVA",
    HelpCommand = "help(VA)",  # which may not exist!
    DialogHeader = "VA Cancer Prediction",
    PropertyList = c("SPropInvisibleReturnObject","VAtreat",
       "VAage", "VAKarn", "VAdiag", "VAcell", "VAprior"),
    CallBackFunction = "backVA",
    ArgumentList = "#0=SPropInvisibleReturnObject, #1=VAtreat,
      #2=VAage, #3=VAKarn, #4=VAdiag, #5=VAcell, #6=VAprior")

guiCreate("Property", Name="VAtreat", DialogPrompt="Treatment",
          DialogControl="List Box", OptionList="standard, test",
          DefaultValue="standard", UseQuotes=T)
guiCreate("Property", Name="VAcell", DialogPrompt="Call type",
          DialogControl="List Box",
          OptionList="squamous, small, adeno, large",
          DefaultValue="squamous", UseQuotes=T)
guiCreate("Property", Name="VAprior",
          DialogPrompt="Prior treatment",
          DialogControl="List Box", OptionList="no, yes",
          DefaultValue="no", UseQuotes=T)
guiCreate("Property", Name="VAage",
          DialogPrompt="Age (years)",
          DialogControl="Float",
          DefaultValue="", IsRequired=T)
guiCreate("Property", Name="VAKarn",
          DialogPrompt="Karnofsky score",
          DialogControl="Float Slider", Range=0:100,
          DefaultValue="", IsRequired=T)
guiCreate("Property", Name="VAdiag",
          DialogPrompt="Time since diagnosis (months)",
          DialogControl="Float",
          DefaultValue="", IsRequired=T)
backVA <- function(df)
{
  activeprop <- cbGetActiveProp(df)
  activevalue <- cbGetCurrValue(df, activeprop)
  switch(activeprop,
     VAKarn = {
       activevalue <- as.numeric(activevalue)
       if(activevalue < 0) {
         df <-  cbSetCurrValue(df, "VAKarn", 0)
         guiCreate("MessageBox",
                   String="0 <= Karnofsky score <= 100")
       }
       if(activevalue > 100) {
         df <-  cbSetCurrValue(df, "VAKarn", 100)
         guiCreate("MessageBox",
                   String="0 <= Karnofsky score <= 100")
       }
     },
     VAage = {
       activevalue <- as.numeric(activevalue)
       if(activevalue < 0) {
         df <-  cbSetCurrValue(df, "VAage", 0)
         guiCreate("MessageBox", String="Age must be positive")
       }},
     VAdiag = {
       activevalue <- as.numeric(activevalue)
       if(activevalue < 0) {
         guiCreate("MessageBox",
                   String="Time to diagnosis must be positive")
         df <-  cbSetCurrValue(df, "VAdiag", 0)
       }}
        )
  df
}
